# Copyright (c) 2016-present, Facebook, Inc.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.


class Error:
    autogenerated = False  # type: bool
    external = False  # type: bool

    def __init__(
        self, autogenerated: bool = False, external: bool = False, **error
    ) -> None:
        self.line = error["line"]
        self.column = error["column"]
        self.path = error["path"]
        self.code = error["code"]
        self.name = error["name"]
        self.description = error["description"]
        self.inference = error["inference"]
        self.autogenerated = autogenerated
        self.external = external

    def __repr__(self):
        return self.__key() + " " + self.description

    def __key(self):
        return self.path + ":" + str(self.line) + ":" + str(self.column)

    def __eq__(self, other):
        return self.__key() == other.__key()

    def __lt__(self, other):
        return self.__key() < other.__key()

    def __hash__(self):
        return hash(self.__key())

    def is_autogenerated(self) -> bool:
        return self.autogenerated

    def is_external(self) -> bool:
        return self.external
